@@ -1,4 +1,4 @@
-function [result,info] = check(M, options, oo)
+function [eigenvalues_,result,info] = check(M, options, oo)
 % Checks determinacy conditions by computing the generalized eigenvalues.
 
 %@info:
@@ -21,6 +21,8 @@ function [result,info] = check(M, options, oo)
 %! @strong{Outputs}
 %! @sp 1
 %! @table @ @var
+%! @item eigenvalues_
+%! Eigenvalues of the model.
 %! @item result
 %! Integer scalar equal to one (BK conditions are satisfied) or zero (otherwise).
 %! @item info
@@ -38,7 +40,7 @@ function [result,info] = check(M, options, oo)
 %! @end deftypefn
 %@eod:
 
-% Copyright (C) 2001-2011 Dynare Team
+% Copyright (C) 2001-2013 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -70,8 +72,6 @@ oo.dr=set_state_space(oo.dr,M);
 
 [dr,info,M,options,oo] = resol(1,M,options,oo);
 
-oo.dr = dr;
-
 if info(1) ~= 0 && info(1) ~= 3 && info(1) ~= 4
     print_info(info, options.noprint);
 end
@@ -86,7 +86,7 @@ end;
 n_explod = nnz(abs(eigenvalues_) > options.qz_criterium);
 
 result = 0;
-if (nyf== n_explod) && (dr.rank == nyf)
+if (nyf== n_explod) && (dr.full_rank)
     result = 1;
 end
 
@@ -99,7 +99,7 @@ if options.noprint == 0
     disp(sprintf('\nThere are %d eigenvalue(s) larger than 1 in modulus ', n_explod));
     disp(sprintf('for %d forward-looking variable(s)',nyf));
     disp(' ')
-    if dr.rank == nyf && nyf == n_explod
+    if result
         disp('The rank condition is verified.')
     else
         disp('The rank conditions ISN''T verified!')
