@@ -130,22 +130,7 @@ function [fval,DLIK,Hess,exit_flag,ys,trend_coeff,info,Model,DynareOptions,Bayes
 
 % AUTHOR(S) stephane DOT adjemian AT univ DASH lemans DOT FR
 
-% Declaration of the penalty as a persistent variable.
-
-% Persistent variable 'penalty' is used to compute an endogenous penalty to
-% the value 'fval' when various conditions are encountered. These conditions
-% set also 'exit_flag' equal to 0 instead of 1.  It is only when
-% dsge_likelihood() is called by an optimizer called by
-% dynare_estimation_1() that 'exit_flag' is ignored and penalized 'fval' is
-% actually used.
-% In that case, 'penalty' is properly initialized, at the very end of the
-% present function, by a call to dsge_likelihood() made in
-% initial_estimation_checks(). If a condition triggers exit_flag ==
-% 0, initial_estimation_checks() triggers an error.
-% In summary, an initial call to the present function, without triggering
-% any condition, guarantees that 'penalty' is properly initialized when needed.
-
-persistent penalty prior_penalty
+global objective_function_penalty_base
 
 % Initialization of the returned variables and others...
 fval        = [];
@@ -181,6 +166,10 @@ if nargout==1,
     analytic_derivation=0;
 end
 
+if analytic_derivation,
+    kron_flag=DynareOptions.analytic_derivation_mode;
+end
+
 %------------------------------------------------------------------------------
 % 1. Get the structural parameters & define penalties
 %------------------------------------------------------------------------------
@@ -188,11 +177,7 @@ end
 % Return, with endogenous penalty, if some parameters are smaller than the lower bound of the prior domain.
 if ~isequal(DynareOptions.mode_compute,1) && any(xparam1<BayesInfo.lb)
     k = find(xparam1<BayesInfo.lb);
-    fval = penalty+sum((BayesInfo.lb(k)-xparam1(k)).^2);
-    xtemp=xparam1;
-    xtemp(k)=BayesInfo.lb(k);
-    prior_correction = max(0,-prior_penalty-priordens(xtemp,BayesInfo.pshape,BayesInfo.p6,BayesInfo.p7,BayesInfo.p3,BayesInfo.p4));
-    fval = fval+prior_correction;
+    fval = objective_function_penalty_base+sum((BayesInfo.lb(k)-xparam1(k)).^2);
     exit_flag = 0;
     info = 41;
     if analytic_derivation,
@@ -204,11 +189,7 @@ end
 % Return, with endogenous penalty, if some parameters are greater than the upper bound of the prior domain.
 if ~isequal(DynareOptions.mode_compute,1) && any(xparam1>BayesInfo.ub)
     k = find(xparam1>BayesInfo.ub);
-    fval = penalty+sum((xparam1(k)-BayesInfo.ub(k)).^2);
-    xtemp=xparam1;
-    xtemp(k)=BayesInfo.ub(k);
-    prior_correction = max(0,-prior_penalty -priordens(xtemp,BayesInfo.pshape,BayesInfo.p6,BayesInfo.p7,BayesInfo.p3,BayesInfo.p4));
-    fval = fval+prior_correction;
+    fval = objective_function_penalty_base+sum((xparam1(k)-BayesInfo.ub(k)).^2);
     exit_flag = 0;
     info = 42;
     if analytic_derivation,
@@ -232,7 +213,7 @@ if EstimatedParameters.ncx
         a = diag(eig(Q));
         k = find(a < 0);
         if k > 0
-            fval = penalty+sum(-a(k));
+            fval = objective_function_penalty_base+sum(-a(k));
             exit_flag = 0;
             info = 43;
             return
@@ -249,7 +230,7 @@ if EstimatedParameters.ncn
         a = diag(eig(H));
         k = find(a < 0);
         if k > 0
-            fval = penalty+sum(-a(k));
+            fval = objective_function_penalty_base+sum(-a(k));
             exit_flag = 0;
             info = 44;
             return
@@ -267,7 +248,7 @@ end
 
 % Return, with endogenous penalty when possible, if dynare_resolve issues an error code (defined in resol).
 if info(1) == 1 || info(1) == 2 || info(1) == 5 || info(1) == 7 || info(1) == 22 || info(1) == 24
-    fval = penalty+1;
+    fval = objective_function_penalty_base+1;
     info = info(1);
     exit_flag = 0;
     if analytic_derivation,
@@ -275,7 +256,7 @@ if info(1) == 1 || info(1) == 2 || info(1) == 5 || info(1) == 7 || info(1) == 22
     end
     return
 elseif info(1) == 3 || info(1) == 4 || info(1)==6 ||info(1) == 19 || info(1) == 20 || info(1) == 21  || info(1) == 23
-    fval = penalty+info(2);
+    fval = objective_function_penalty_base+info(2);
     info = info(1);
     exit_flag = 0;
     if analytic_derivation,
@@ -445,6 +426,13 @@ switch DynareOptions.lik_init
                                                         T,R,Q,H1,Z,mmm,pp,rr);
         diffuse_periods = length(dlik);
     end
+    if isnan(dLIK),
+        info = 45;
+        fval = objective_function_penalty_base + 100;
+        exit_flag = 0;
+        return
+    end
+    
   case 4% Start from the solution of the Riccati equation.
     if kalman_algo ~= 2
         kalman_algo = 1;
@@ -484,6 +472,7 @@ if analytic_derivation,
     end
     DLIK = [];
     AHess = [];
+    iv = DynareResults.dr.restrict_var_list;
     if nargin<8 || isempty(derivatives_info)
         [A,B,nou,nou,Model,DynareOptions,DynareResults] = dynare_resolve(Model,DynareOptions,DynareResults);
         if ~isempty(EstimatedParameters.var_exo)
@@ -498,14 +487,15 @@ if analytic_derivation,
         end
 
         if full_Hess,
-            [dum, DT, DOm, DYss, dum2, D2T, D2Om, D2Yss] = getH(A, B, Model,DynareResults,0,indparam,indexo);
+            [dum, DT, DOm, DYss, dum2, D2T, D2Om, D2Yss] = getH(A, B, Model,DynareResults,DynareOptions,kron_flag,indparam,indexo,iv);
+            clear dum dum2;
         else
-            [dum, DT, DOm, DYss] = getH(A, B, Model,DynareResults,0,indparam,indexo);
+            [dum, DT, DOm, DYss] = getH(A, B, Model,DynareResults,DynareOptions,kron_flag,indparam,indexo,iv);
         end
     else
-        DT = derivatives_info.DT;
-        DOm = derivatives_info.DOm;
-        DYss = derivatives_info.DYss;
+        DT = derivatives_info.DT(iv,iv,:);
+        DOm = derivatives_info.DOm(iv,iv,:);
+        DYss = derivatives_info.DYss(iv,:);
         if isfield(derivatives_info,'full_Hess'),
             full_Hess = derivatives_info.full_Hess;
         end
@@ -519,11 +509,7 @@ if analytic_derivation,
         end
         clear('derivatives_info');
     end
-    iv = DynareResults.dr.restrict_var_list;
     DYss = [zeros(size(DYss,1),offset) DYss];
-    DT = DT(iv,iv,:);
-    DOm = DOm(iv,iv,:);
-    DYss = DYss(iv,:);
     DH=zeros([length(H),length(H),length(xparam1)]);
     DQ=zeros([size(Q),length(xparam1)]);
     DP=zeros([size(T),length(xparam1)]);
@@ -532,29 +518,30 @@ if analytic_derivation,
         tmp(j,:,:) = blkdiag(zeros(offset,offset), squeeze(D2Yss(j,:,:)));
         end
         D2Yss = tmp;
-        D2T = D2T(iv,iv,:,:);
-        D2Om = D2Om(iv,iv,:,:);
-        D2Yss = D2Yss(iv,:,:);
-        D2H=zeros([size(H),length(xparam1),length(xparam1)]);
-        D2P=zeros([size(T),length(xparam1),length(xparam1)]);
+        D2H=sparse(size(D2Om,1),size(D2Om,2)); %zeros([size(H),length(xparam1),length(xparam1)]);
+        D2P=sparse(size(D2Om,1),size(D2Om,2)); %zeros([size(T),length(xparam1),length(xparam1)]);
+        jcount=0;
     end
+    if DynareOptions.lik_init==1,
     for i=1:EstimatedParameters.nvx
         k =EstimatedParameters.var_exo(i,1);
         DQ(k,k,i) = 2*sqrt(Q(k,k));
         dum =  lyapunov_symm(T,DOm(:,:,i),DynareOptions.qz_criterium,DynareOptions.lyapunov_complex_threshold);
-        kk = find(abs(dum) < 1e-12);
-        dum(kk) = 0;
+%         kk = find(abs(dum) < 1e-12);
+%         dum(kk) = 0;
         DP(:,:,i)=dum;
         if full_Hess
         for j=1:i,
-            dum =  lyapunov_symm(T,D2Om(:,:,i,j),DynareOptions.qz_criterium,DynareOptions.lyapunov_complex_threshold);
-            kk = (abs(dum) < 1e-12);
-            dum(kk) = 0;
-            D2P(:,:,i,j)=dum;
-            D2P(:,:,j,i)=dum;
+            jcount=jcount+1;
+            dum =  lyapunov_symm(T,dyn_unvech(D2Om(:,jcount)),DynareOptions.qz_criterium,DynareOptions.lyapunov_complex_threshold);
+%             kk = (abs(dum) < 1e-12);
+%             dum(kk) = 0;
+            D2P(:,jcount)=dyn_vech(dum);
+%             D2P(:,:,j,i)=dum;
         end
         end
     end
+    end
     offset = EstimatedParameters.nvx;
     for i=1:EstimatedParameters.nvn
         k = EstimatedParameters.var_endo(i,1);
@@ -564,31 +551,35 @@ if analytic_derivation,
         end
     end
     offset = offset + EstimatedParameters.nvn;
+    if DynareOptions.lik_init==1,
     for j=1:EstimatedParameters.np
         dum =  lyapunov_symm(T,DT(:,:,j+offset)*Pstar*T'+T*Pstar*DT(:,:,j+offset)'+DOm(:,:,j+offset),DynareOptions.qz_criterium,DynareOptions.lyapunov_complex_threshold);
-        kk = find(abs(dum) < 1e-12);
-        dum(kk) = 0;
+%         kk = find(abs(dum) < 1e-12);
+%         dum(kk) = 0;
         DP(:,:,j+offset)=dum;
         if full_Hess
         DTj = DT(:,:,j+offset);
         DPj = dum;
-        for i=1:j,
-            DTi = DT(:,:,i+offset);
-            DPi = DP(:,:,i+offset);
-            D2Tij = D2T(:,:,i,j);
-            D2Omij = D2Om(:,:,i,j);
+        for i=1:j+offset,
+            jcount=jcount+1;
+            DTi = DT(:,:,i);
+            DPi = DP(:,:,i);
+            D2Tij = reshape(D2T(:,jcount),size(T));
+            D2Omij = dyn_unvech(D2Om(:,jcount));
             tmp = D2Tij*Pstar*T' + T*Pstar*D2Tij' + DTi*DPj*T' + DTj*DPi*T' + T*DPj*DTi' + T*DPi*DTj' + DTi*Pstar*DTj' + DTj*Pstar*DTi' + D2Omij;
             dum = lyapunov_symm(T,tmp,DynareOptions.qz_criterium,DynareOptions.lyapunov_complex_threshold);
-            dum(abs(dum)<1.e-12) = 0;
-            D2P(:,:,i+offset,j+offset) = dum;
-            D2P(:,:,j+offset,i+offset) = dum;
+%             dum(abs(dum)<1.e-12) = 0;
+            D2P(:,jcount) = dyn_vech(dum);
+%             D2P(:,:,j+offset,i) = dum;
         end
         end
     end
+    end
     if analytic_derivation==1,
         analytic_deriv_info={analytic_derivation,DT,DYss,DOm,DH,DP,asy_Hess};
     else
         analytic_deriv_info={analytic_derivation,DT,DYss,DOm,DH,DP,D2T,D2Yss,D2Om,D2H,D2P};
+        clear DT DYss DOm DH DP D2T D2Yss D2Om D2H D2P,
     end
 else
     analytic_deriv_info={0};
@@ -724,12 +715,14 @@ end
 
 if isnan(LIK)
     info = 45;
+    fval = objective_function_penalty_base + 100;
     exit_flag = 0;
     return
 end
 
 if imag(LIK)~=0
     info = 46;
+    fval = objective_function_penalty_base + 100;
     exit_flag = 0;
     return
 end
@@ -762,12 +755,14 @@ fval    = (likelihood-lnprior);
 
 if isnan(fval)
     info = 47;
+    fval = objective_function_penalty_base + 100;
     exit_flag = 0;
     return
 end
 
 if imag(fval)~=0
     info = 48;
+    fval = objective_function_penalty_base + 100;
     exit_flag = 0;
     return
 end
@@ -775,10 +770,6 @@ end
 % Update DynareOptions.kalman_algo.
 DynareOptions.kalman_algo = kalman_algo;
 
-% Update the penalty.
-penalty = fval;
-prior_penalty = -lnprior;
-
 if analytic_derivation==0 && nargout==2,
     lik=lik(start:end,:);
     DLIK=[-lnprior; lik(:)];
