@@ -15,7 +15,7 @@ function dynareroot = dynare_config(path_to_dynare,verbose)
 % SPECIAL REQUIREMENTS
 %   none
 
-% Copyright (C) 2001-2012 Dynare Team
+% Copyright (C) 2001-2013 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -86,6 +86,11 @@ if ~exist('OCTAVE_VERSION') && matlab_ver_less_than('7.4')
     addpath([dynareroot '/missing/bsxfun'])
 end
 
+% ilu is missing in old versions of MATLAB and in Octave
+if exist('OCTAVE_VERSION') || matlab_ver_less_than('7.4')
+    addpath([dynareroot '/missing/ilu'])
+end
+
 % nanmean is in Octave Forge Statistics package and in MATLAB Statistics
 % toolbox
 if (exist('OCTAVE_VERSION') && ~user_has_octave_forge_package('statistics')) ...
@@ -110,7 +115,7 @@ else
                 addpath(mexpath)
             end
         else
-            mexpath = [dynareroot '../mex/matlab/win32-7.5-8.0'];
+            mexpath = [dynareroot '../mex/matlab/win32-7.5-8.1'];
             if exist(mexpath, 'dir')
                 addpath(mexpath)
             end
@@ -135,7 +140,7 @@ else
                 addpath(mexpath)
             end
         else
-            mexpath = [dynareroot '../mex/matlab/win64-7.8-8.0'];
+            mexpath = [dynareroot '../mex/matlab/win64-7.8-8.1'];
             if exist(mexpath, 'dir')
                 addpath(mexpath)
             end
@@ -149,7 +154,7 @@ else
                 addpath(mexpath)
             end
         else
-            mexpath = [dynareroot '../mex/matlab/osx32-7.5-8.0'];
+            mexpath = [dynareroot '../mex/matlab/osx32-7.5-8.1'];
             if exist(mexpath, 'dir')
                 addpath(mexpath)
             end
