@@ -66,6 +66,9 @@ if ~isempty(options_gsa.datafile) || isempty(bayestopt_),
     if isfield(options_gsa,'lik_init'),
         options_.lik_init=options_gsa.lik_init;
     end
+    if isfield(options_gsa,'kalman_algo'),
+        options_.kalman_algo=options_gsa.kalman_algo;
+    end
     options_.mode_compute = 0;
     options_.filtered_vars = 1;
     options_.plot_priors = 0;
@@ -125,7 +128,7 @@ options_gsa = set_default_option(options_gsa,'Nsam',2048);
 options_gsa = set_default_option(options_gsa,'load_redform',0);
 options_gsa = set_default_option(options_gsa,'load_rmse',0);
 options_gsa = set_default_option(options_gsa,'load_stab',0);
-options_gsa = set_default_option(options_gsa,'alpha2_stab',0.3);
+options_gsa = set_default_option(options_gsa,'alpha2_stab',0);
 options_gsa = set_default_option(options_gsa,'ksstat',0.1);
 options_gsa = set_default_option(options_gsa,'pvalue_ks',0.001);
 options_gsa = set_default_option(options_gsa,'pvalue_corr',0.001);
@@ -215,6 +218,11 @@ end
 
 if options_gsa.stab && ~options_gsa.ppost,
     x0 = stab_map_(OutputDirectoryName,options_gsa);
+    if isempty(x0),
+        disp(' ')
+        disp('Sensitivity computations stopped: no parameter set provided a unique solution')
+        return
+    end
 end
 
 % reduced form
@@ -225,8 +233,32 @@ if options_gsa.identification,
     map_ident_(OutputDirectoryName,options_gsa);
 end
 
-if options_gsa.redform && ~isempty(options_gsa.namendo) ...
-        && ~options_gsa.ppost,
+if options_gsa.redform && ~isempty(options_gsa.namendo),% ...
+    %         && ~options_gsa.ppost,
+    if options_gsa.ppost,
+        filnam = dir([M_.dname filesep 'metropolis' filesep '*param_irf*.mat']);
+        lpmat=[];
+        for j=1:length(filnam),
+            load ([M_.dname filesep 'metropolis' filesep M_.fname '_param_irf' int2str(j) '.mat'])
+            lpmat=[lpmat; stock];
+        end
+        clear stock
+        nshock = estim_params_.nvx;
+        nshock = nshock + estim_params_.nvn;
+        nshock = nshock + estim_params_.ncx;
+        nshock = nshock + estim_params_.ncn;
+        
+        lpmat0=lpmat(:,1:nshock);
+        lpmat=lpmat(:,nshock+1:end);
+        istable=(1:size(lpmat,1));
+        iunstable=[];
+        iwrong=[];
+        iindeterm=[];
+        save([OutputDirectoryName filesep M_.fname '_mc.mat'],'lpmat','lpmat0','istable','iunstable','iwrong','iindeterm')
+        options_gsa.load_stab=1;
+        
+        x0 = stab_map_(OutputDirectoryName,options_gsa);
+    end
     if strmatch(':',options_gsa.namendo,'exact'),
         options_gsa.namendo=M_.endo_names;
     end
@@ -281,24 +313,42 @@ if options_gsa.rmse,
                options_.filtered_vars=0;               
            end
 %             dynare_MC([],OutputDirectoryName,data,rawdata,data_info);
-            prior_posterior_statistics('gsa',dataset_);
-            if options_.bayesian_irf
-                PosteriorIRF('gsa');
+        if options_gsa.pprior
+            TmpDirectoryName = ([M_.dname filesep 'gsa' filesep 'prior']);
+        else
+            TmpDirectoryName = ([M_.dname filesep 'gsa' filesep 'mc']);
+        end
+        if exist(TmpDirectoryName,'dir');
+            mydelete([M_.fname '_filter_step_ahead*.mat'],[TmpDirectoryName filesep]);
+            mydelete([M_.fname '_inno*.mat'],[TmpDirectoryName filesep]);
+            mydelete([M_.fname '_smooth*.mat'],[TmpDirectoryName filesep]);
+            mydelete([M_.fname '_update*.mat'],[TmpDirectoryName filesep]);
+            filparam = dir([TmpDirectoryName filesep M_.fname '_param*.mat']);
+            for j=1:length(filparam),
+                if isempty(strmatch([M_.fname '_param_irf'],filparam(j).name))
+                    delete([TmpDirectoryName filesep filparam(j).name]);
+                end
             end
-            options_gsa.load_rmse=0;
-            %   else
-            %     if options_gsa.load_rmse==0,
-            %       disp('You already saved a MC filter/smoother analysis ')
-            %       disp('Do you want to overwrite ?')
-            %       pause;
-            %       if options_gsa.pprior
-            %         delete([OutputDirectoryName,'/',fname_,'_prior_*.mat'])
-            %       else
-            %         delete([OutputDirectoryName,'/',fname_,'_mc_*.mat'])
-            %       end
-            %       dynare_MC([],OutputDirectoryName);
-            %       options_gsa.load_rmse=0;
-            %     end    
+            
+        end
+        prior_posterior_statistics('gsa',dataset_);
+        if options_.bayesian_irf
+            PosteriorIRF('gsa');
+        end
+        options_gsa.load_rmse=0;
+        %   else
+        %     if options_gsa.load_rmse==0,
+        %       disp('You already saved a MC filter/smoother analysis ')
+        %       disp('Do you want to overwrite ?')
+        %       pause;
+        %       if options_gsa.pprior
+        %         delete([OutputDirectoryName,'/',fname_,'_prior_*.mat'])
+        %       else
+        %         delete([OutputDirectoryName,'/',fname_,'_mc_*.mat'])
+        %       end
+        %       dynare_MC([],OutputDirectoryName);
+        %       options_gsa.load_rmse=0;
+        %     end
             
         end
     end
