@@ -370,6 +370,7 @@ options_.mh_autocorrelation_function_size = 30;
 options_.plot_priors = 1;
 options_.cova_compute = 1;
 options_.parallel = 0;
+options_.parallel_info.isHybridMatlabOctave = false;
 options_.parallel_info.leaveSlaveOpen = 0;
 options_.parallel_info.RemoteTmpFolder = '';
 options_.number_of_grid_points_for_kde = 2^9;
@@ -400,6 +401,7 @@ oo_.exo_det_simul = [];
 M_.params = [];
 M_.endo_histval = [];
 M_.Correlation_matrix = [];
+M_.Correlation_matrix_ME = [];
 
 % homotopy
 options_.homotopy_mode = 0;
