@@ -202,7 +202,7 @@ if ~loadSA,
         clear stock_filter;
     end
     for j=1:nruns,
-        lnprior(j,1) = priordens(x(j,:)',bayestopt_.pshape,bayestopt_.p1,bayestopt_.p2,bayestopt_.p3,bayestopt_.p4);
+        lnprior(j,1) = priordens(x(j,:)',bayestopt_.pshape,bayestopt_.p6,bayestopt_.p7,bayestopt_.p3,bayestopt_.p4);
     end
     likelihood=logpo2(:)-lnprior(:);
     disp('... done!')
@@ -310,9 +310,6 @@ else
                     dyn_saveas(hh,[OutDir '/' fname_ '_rmse_mc_lnprior',int2str(ifig) ],options_);
                 end
             end
-            if ~options_.nodisplay
-                close(hh);
-            end
         end
     end
     ifig=0;
@@ -341,9 +338,6 @@ else
                     dyn_saveas(hh,[OutDir '/' fname_ '_rmse_mc_lnlik',int2str(ifig) ],options_);
                 end
             end
-            if ~options_.nodisplay
-                close(hh);
-            end
         end
     end
     ifig=0;
@@ -372,9 +366,6 @@ else
                     dyn_saveas(hh,[OutDir '/' fname_ '_rmse_mc_lnpost',int2str(ifig)],options_);
                 end
             end
-            if ~options_.nodisplay
-                close(hh);
-            end
         end
     end
     end
@@ -524,7 +515,6 @@ else
             end
         end
     end
-    close all
     end
     
     for j=1:size(SP,2),
