@@ -54,7 +54,11 @@ if opt_gsa.load_ident_files==0,
   mss = yys(bayestopt_.mfys,:);
   mss = teff(mss(:,istable),Nsam,istable);
   yys = teff(yys(oo_.dr.order_var,istable),Nsam,istable);
-  [vdec, cc, ac] = mc_moments(T, lpmatx, oo_.dr);
+  if exist('T'),
+      [vdec, cc, ac] = mc_moments(T, lpmatx, oo_.dr);
+  else
+      return,
+  end
 
 
   if opt_gsa.morris==2,
@@ -96,9 +100,6 @@ if opt_gsa.load_ident_files==0,
       title(M_.exo_names(j,:),'interpreter','none')
       if mod(j,6)==0 | j==M_.exo_nbr,
         dyn_saveas(hh,[OutputDirectoryName,'/',fname_,'_vdec_exo_',int2str(ifig)],options_);  
-        if ~options_.nodisplay
-            close(hh);
-        end      
       end
     end
   end
@@ -124,7 +125,9 @@ if opt_gsa.load_ident_files==0,
 %     bayestopt_.restrict_aux, M_.exo_nbr);
   A = zeros(size(Aa,1),size(Aa,2)+size(Aa,1),length(istable));
   % Sig(estim_params_.var_exo(:,1))=lpmatx(1,:).^2;
-  set_shocks_param(lpmatx(1,:));
+  if ~isempty(lpmatx),
+      set_shocks_param(lpmatx(1,:));
+  end
   A(:,:,1)=[Aa, triu(Bb*M_.Sigma_e*Bb')];
   for j=2:length(istable),
     dr.ghx = T(:, [1:(nc1-M_.exo_nbr)],j);
@@ -133,7 +136,9 @@ if opt_gsa.load_ident_files==0,
 %       bayestopt_.restrict_var_list, ...
 %       bayestopt_.restrict_columns, ...
 %       bayestopt_.restrict_aux, M_.exo_nbr);
-    set_shocks_param(lpmatx(j,:));
+    if ~isempty(lpmatx),
+        set_shocks_param(lpmatx(j,:));
+    end
     A(:,:,j)=[Aa, triu(Bb*M_.Sigma_e*Bb')];
   end
   clear T;
@@ -218,9 +223,6 @@ if opt_gsa.morris==1,
   xlabel(' ')
   title('All variance decomposition')
   dyn_saveas(hh,[OutputDirectoryName,'/',fname_,'_morris_vdec'],options_);
-  if ~options_.nodisplay
-    close(hh);
-  end
   else
   save([OutputDirectoryName,'/',fname_,'_morris_IDE'],'vdec')
     
@@ -737,9 +739,6 @@ if opt_gsa.morris==1,
   xlabel(' ')
   title('\mu in the model')
   dyn_saveas(hh,[OutputDirectoryName,'/',fname_,'_morrismu_par'],options_);
-  if ~options_.nodisplay
-    close(hh);
-  end
 
   hh=dyn_figure(options_); %bar(SAsignorm(:,irel))
 %   boxplot(SAsignorm','whis',10,'symbol','r.')
@@ -755,9 +754,6 @@ if opt_gsa.morris==1,
   xlabel(' ')
   title('\sigma in the model')
   dyn_saveas(hh,[OutputDirectoryName,'/',fname_,'_morrissig_par'],options_);
-  if ~options_.nodisplay
-    close(hh);
-  end
 
   %     figure, bar(SAnorm(:,irel)')
   %     set(gca,'xtick',[1:j0])
