@@ -73,6 +73,11 @@ if ~exist('T')
     else
         load([dirname,'/',M_.fname,'_mc'],'T');
     end
+    if ~exist('T'),
+        disp('The model is too large!')
+        disp('Reduced form mapping stopped!')
+        return
+    end
 end
 if isempty(dir(adir))
     mkdir(adir)
@@ -129,16 +134,13 @@ for j=1:size(anamendo,1)
                     else
                         iy=find( (y0>threshold(1)) & (y0<threshold(2)));
                         iyc=find( (y0<=threshold(1)) | (y0>=threshold(2)));
-                        xdir = [xdir0,'_cut'];
+                        xdir = [xdir0,'_threshold'];
                         if isempty(dir(xdir))
                             mkdir(xdir)
                         end
                         if ~options_.nograph,
                             hf=dyn_figure(options_); hist(y0,30), title([namendo,' vs. ', namexo])
                             dyn_saveas(hf,[xdir,'/', namendo,'_vs_', namexo],options_);
-                            if ~options_.nodisplay
-                                close(hf);
-                            end
                         end
                         %             if ~isempty(iy),
                         %               si(:,js) = redform_private(x0(iy,:), y0(iy), pshape, pd, iload, pnames, namendo, namexo, xdir, options_gsa_);
@@ -146,21 +148,21 @@ for j=1:size(anamendo,1)
                         si(:,js) = NaN(np,1);
                         %             end
                         if ~isempty(iy) && ~isempty(iyc)
-                            delete([xdir, '/*cut*.*'])
-                            [proba, dproba] = stab_map_1(x0, iy, iyc, 'cut',0);
+                            delete([xdir, '/*threshold*.*'])
+                            [proba, dproba] = stab_map_1(x0, iy, iyc, 'threshold',0);
                             %             indsmirnov = find(dproba>ksstat);
                             indsmirnov = find(proba<pvalue_ks);
                             for jp=1:length(indsmirnov),
                                 disp([M_.param_names(estim_params_.param_vals(indsmirnov(jp),1),:),'   d-stat = ', num2str(dproba(indsmirnov(jp)),'%1.3f'),'   p-value = ', num2str(proba(indsmirnov(jp)),'%1.3f')])
                             end
                             disp(' ');
-                            stab_map_1(x0, iy, iyc, 'cut',1,indsmirnov,xdir);
-                            stab_map_2(x0(iy,:),alpha2,pvalue_corr,'cut',xdir)
-                            stab_map_2(x0(iyc,:),alpha2,pvalue_corr,'trim',xdir)
+                            stab_map_1(x0, iy, iyc, 'threshold',1,indsmirnov,xdir);
+                            stab_map_2(x0(iy,:),alpha2,pvalue_corr,'inside_threshold',xdir)
+                            stab_map_2(x0(iyc,:),alpha2,pvalue_corr,'outside_threshold',xdir)
                             lpmat=x0(iy,:);
                             lpmat0=xx0(iy,:);
                             istable=[1:length(iy)];
-                            save([xdir,filesep,'threshold.mat'],'lpmat','lpmat0','istable')
+                            save([xdir,filesep,'threshold.mat'],'lpmat','lpmat0','istable','y0','x0','xx0','iy','iyc')
                             clear lpmat lpmat0 istable
                         end
                     end
@@ -193,9 +195,6 @@ for j=1:size(anamendo,1)
                     title([logflag,' ',namendo,' vs. ',namexo],'interpreter','none')
                     if iplo==9,
                         dyn_saveas(hfig,[dirname,'/',M_.fname,'_redform_', namendo,'_vs_shocks_',logflag,num2str(ifig)],options_);
-                        if ~options_.nodisplay
-                            close(hfig);
-                        end
                     end
                 end
                 
@@ -204,9 +203,6 @@ for j=1:size(anamendo,1)
     end
     if iplo<9 && iplo>0 && ifig && ~options_.nograph,
         dyn_saveas(hfig,[dirname,'/',M_.fname,'_redform_', namendo,'_vs_shocks_',logflag,num2str(ifig)],options_);
-        if ~options_.nodisplay
-            close(hfig);
-        end
     end
     ifig=0;
     iplo=0;
@@ -237,7 +233,7 @@ for j=1:size(anamendo,1)
                     else
                         iy=find( (y0>threshold(1)) & (y0<threshold(2)));
                         iyc=find( (y0<=threshold(1)) | (y0>=threshold(2)));
-                        xdir = [xdir0,'_cut'];
+                        xdir = [xdir0,'_threshold'];
                         if isempty(dir(xdir))
                             mkdir(xdir)
                         end
@@ -247,26 +243,23 @@ for j=1:size(anamendo,1)
                         if ~options_.nograph,
                             hf=dyn_figure(options_); hist(y0,30), title([namendo,' vs. ', namlagendo])
                             dyn_saveas(hf,[xdir,'/', namendo,'_vs_', namlagendo],options_);
-                            if ~options_.nodisplay
-                                close(hf);
-                            end
                         end
                         if ~isempty(iy) && ~isempty(iyc),
-                            delete([xdir, '/*cut*.*'])
-                            [proba, dproba] = stab_map_1(x0, iy, iyc, 'cut',0);
+                            delete([xdir, '/*threshold*.*'])
+                            [proba, dproba] = stab_map_1(x0, iy, iyc, 'threshold',0);
                             %           indsmirnov = find(dproba>ksstat);
                             indsmirnov = find(proba<pvalue_ks);
                             for jp=1:length(indsmirnov),
                                 disp([M_.param_names(estim_params_.param_vals(indsmirnov(jp),1),:),'   d-stat = ', num2str(dproba(indsmirnov(jp)),'%1.3f'),'   p-value = ', num2str(proba(indsmirnov(jp)),'%1.3f')])
                             end
                             disp(' ');
-                            stab_map_1(x0, iy, iyc, 'cut',1,indsmirnov,xdir);
-                            stab_map_2(x0(iy,:),alpha2,pvalue_corr,'cut',xdir)
-                            stab_map_2(x0(iyc,:),alpha2,pvalue_corr,'trim',xdir)
+                            stab_map_1(x0, iy, iyc, 'threshold',1,indsmirnov,xdir);
+                            stab_map_2(x0(iy,:),alpha2,pvalue_corr,'inside_threshold',xdir)
+                            stab_map_2(x0(iyc,:),alpha2,pvalue_corr,'outside_threshold',xdir)
                             lpmat=x0(iy,:);
                             lpmat0=xx0(iy,:);
                             istable=[1:length(iy)];
-                            save([xdir,filesep,'threshold.mat'],'lpmat','lpmat0','istable')
+                            save([xdir,filesep,'threshold.mat'],'lpmat','lpmat0','istable','y0','x0','xx0','iy','iyc')
                             clear lpmat lpmat0 istable
                             
                         end
@@ -300,9 +293,6 @@ for j=1:size(anamendo,1)
                     title([logflag,' ',namendo,' vs. ',namlagendo,'(-1)'],'interpreter','none')
                     if iplo==9,
                         dyn_saveas(hfig,[dirname,'/',M_.fname,'_redform_', namendo,'_vs_lags_',logflag,num2str(ifig)],options_);
-                        if ~options_.nodisplay
-                            close(hfig);
-                        end
                     end
                 end
                 
@@ -311,9 +301,6 @@ for j=1:size(anamendo,1)
     end
     if iplo<9 && iplo>0 && ifig && ~options_.nograph,
         dyn_saveas(hfig,[dirname,'/',M_.fname,'_redform_', namendo,'_vs_lags_',logflag,num2str(ifig)],options_);
-        if ~options_.nodisplay
-            close(hfig);
-        end
     end
 end
 
@@ -373,9 +360,6 @@ if iload==0,
     if ~options_.nograph,
         hfig=dyn_figure(options_); hist(y0,30), title([namy,' vs. ', namx])
         dyn_saveas(hfig,[xdir,'/', namy,'_vs_', namx],options_);
-        if ~options_.nodisplay
-            close(hfig);
-        end
     end
     %   gsa_ = gsa_sdp_dyn(y0, x0, -2, [],[],[],1,fname, pnames);
     nrun=length(y0);
@@ -391,7 +375,9 @@ if iload==0,
     gsa_.x0=x00(1:nfit,:);
     if ~options_.nograph,
         hfig=gsa_sdp_plot(gsa_,fname,pnames,iii(1:min(12,np)));
-        close(hfig);
+        if options_.nodisplay
+            close(hfig);
+        end
     end
     gsa_.x0=x0(1:nfit,:);
     %   copyfile([fname,'_est.mat'],[fname,'.mat'])
@@ -400,9 +386,6 @@ if iload==0,
         plot(y0(1:nfit),[gsa_.fit y0(1:nfit)],'.'),
         title([namy,' vs. ', namx,' fit'])
         dyn_saveas(hfig,[xdir,'/', namy,'_vs_', namx,'_fit'],options_);
-        if ~options_.nodisplay
-            close(hfig);
-        end
         if nfit<nrun,
             npred=[nfit+1:nrun];
             yf = ss_anova_fcast(x0(npred,:), gsa_);
@@ -410,9 +393,6 @@ if iload==0,
             plot(y0(npred),[yf y0(npred)],'.'),
             title([namy,' vs. ', namx,' pred'])
             dyn_saveas(hfig,[xdir,'/', namy,'_vs_', namx,'_pred'],options_);
-            if ~options_.nodisplay
-                close(hfig);
-            end
         end
         
     end
@@ -425,9 +405,6 @@ else
         plot(y0,[yf y0],'.'),
         title([namy,' vs. ', namx,' pred'])
         dyn_saveas(hfig,[xdir,'/', namy,'_vs_', namx,'_pred'],options_);
-        if ~options_.nodisplay
-            close(hfig);
-        end
     end
 end
 % si = gsa_.multivariate.si;
