@@ -110,9 +110,6 @@ for j=1:npar,
                 title(['cc = ',num2str(c0(i2(jx),j))])
                 if (mod(j2,12)==0) && j2>0,
                     dyn_saveas(hh,[dirname,'/',fig_nam_,int2str(ifig)],options_);
-                    if ~options_.nodisplay
-                        close(hh);
-                    end
                 end
                 end
             end
@@ -121,9 +118,6 @@ for j=1:npar,
     end
     if ~options_.nograph && (j==(npar)) && j2>0 && (mod(j2,12)~=0),
         dyn_saveas(hh,[dirname,'/',fig_nam_,int2str(ifig)],options_);
-        if ~options_.nodisplay
-            close(hh);
-        end
     end
     
 end
