@@ -59,7 +59,7 @@ void
 CheckStatement::writeOutput(ostream &output, const string &basename) const
 {
   options_list.writeOutput(output);
-  output << "check(M_,options_,oo_);\n";
+  output << "oo_.dr.eigval = check(M_,options_,oo_);" << endl;
 }
 
 void
@@ -95,6 +95,9 @@ void
 SimulStatement::checkPass(ModFileStructure &mod_file_struct, WarningConsolidation &warnings)
 {
   mod_file_struct.simul_present = true;
+
+  // The following is necessary to allow shocks+endval+simul in a loop
+  mod_file_struct.shocks_present_but_simul_not_yet = false;
 }
 
 void
@@ -224,6 +227,12 @@ DiscretionaryPolicyStatement::checkPass(ModFileStructure &mod_file_struct, Warni
 {
   mod_file_struct.discretionary_policy_present = true;
 
+  if (options_list.symbol_list_options.find("instruments") == options_list.symbol_list_options.end())
+    {
+      cerr << "ERROR: discretionary_policy: the instruments option is required." << endl;
+      exit(EXIT_FAILURE);
+    }
+
   /* Fill in option_order of mod_file_struct
      Since discretionary policy needs one further order of derivation (for example, for 1st order
      approximation, it needs 2nd derivatives), we add 1 to the order declared by user */
